import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.6817aae4.js";import{R as f}from"./tasksController.687d0fb0.js";import{d as _,ea as y,f as g,o as n,Y as b,b as w,w as k,u as d,c as I,S as T,aS as v,aG as B,dd as S}from"./index.57388330.js";import"./gateway.e592f357.js";import{a as j,B as x}from"./build.27c78c44.js";import{a as C}from"./project.712c73ac.js";import"./tables.01dc6a89.js";import{a as D}from"./asyncComputed.dea6d978.js";import"./metadata.75a6b80a.js";import"./PhWebhooksLogo.vue.2b424bd1.js";import"./ant-design.156ae155.js";import"./string.b6e197ca.js";import"./dayjs.f61a772d.js";import"./index.09157d5c.js";import"./scripts.f92c2c63.js";import"./record.82dac5d0.js";import"./linters.8b6dede8.js";import"./polling.99eba4a7.js";import"./popupNotifcation.cc3d27fb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="01879f21-c9f4-4c64-8299-da2ddd8f76c8",e._sentryDebugIdIdentifier="sentry-dbid-01879f21-c9f4-4c64-8299-da2ddd8f76c8")}catch{}})();const Q=_({__name:"Tasks",setup(e){const a=y().params.projectId,l=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(u=>u.latest);if(!r)return null;const[c,p]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:c,project:p}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),b(v,null,[w(d(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:d(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.321289b9.js.map
