import"./index.57388330.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="cdb0d3ec-2de4-478b-ac39-29022340e3ef",e._sentryDebugIdIdentifier="sentry-dbid-cdb0d3ec-2de4-478b-ac39-29022340e3ef")}catch{}})();function n(e,d){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...d})}export{n as g};
//# sourceMappingURL=datetime.698b1b1d.js.map
