import{P as f}from"./PlayerNavbar.551c89c3.js";import{d as g,eo as h,ea as c,e as y,f as b,r as k,o as i,Y as v,u as a,c as w,S as L,a as C,b as I,a0 as N}from"./index.57388330.js";import{u as V}from"./workspaceStore.3e3a3ada.js";import"./metadata.75a6b80a.js";import"./PhWebhooksLogo.vue.2b424bd1.js";import"./LoadingOutlined.da044905.js";import"./PhSignOut.vue.261bd3d7.js";import"./index.85b4d3b9.js";import"./Avatar.d0198d03.js";import"./url.40a6ac51.js";import"./colorHelpers.ae02acb9.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="765078a8-1651-4c95-90e9-499eb2fc89b6",o._sentryDebugIdIdentifier="sentry-dbid-765078a8-1651-4c95-90e9-499eb2fc89b6")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,n=y(null),d=async({path:s,id:r})=>{n.value=r,await e.push({path:`/${s}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(s,r)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(u),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.e32c0d1f.js.map
