import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.c9c08e1c.js";import{d as l,eo as m,ea as g,o as y,Y as b,b as w,u as n,a0 as k}from"./index.57388330.js";import{u as h}from"./workspaceStore.3e3a3ada.js";import"./Logo.0a698e5e.js";import"./string.b6e197ca.js";import"./CircularLoading.b8405742.js";import"./index.ee7e1ab7.js";import"./index.8cff4063.js";import"./url.40a6ac51.js";import"./colorHelpers.ae02acb9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="74c557fd-47ef-4b50-a913-8cccf76d996e",e._sentryDebugIdIdentifier="sentry-dbid-74c557fd-47ef-4b50-a913-8cccf76d996e")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return y(),b("div",v,[w(f,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.ac28297a.js.map
