import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.6817aae4.js";import{L as i}from"./tasksController.687d0fb0.js";import{d as c,o as p,c as d,w as o,b as s,aG as _,u as a,dd as f,a0 as m}from"./index.57388330.js";import{C as l}from"./ContentLayout.c72cf0b6.js";import"./metadata.75a6b80a.js";import"./PhWebhooksLogo.vue.2b424bd1.js";import"./ant-design.156ae155.js";import"./string.b6e197ca.js";import"./dayjs.f61a772d.js";import"./index.09157d5c.js";import"./gateway.e592f357.js";import"./popupNotifcation.cc3d27fb.js";import"./scripts.f92c2c63.js";import"./record.82dac5d0.js";import"./linters.8b6dede8.js";import"./asyncComputed.dea6d978.js";import"./polling.99eba4a7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f733bb00-bc34-48ba-b4fe-c24dc4062509",t._sentryDebugIdIdentifier="sentry-dbid-f733bb00-bc34-48ba-b4fe-c24dc4062509")}catch{}})();const u=c({__name:"Tasks",setup(t){const e=new i;return(r,b)=>(p(),d(l,null,{default:o(()=>[s(a(f),null,{default:o(()=>[_("Tasks")]),_:1}),s(n,{class:"tasks",api:a(e),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=m(u,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.4db3bbdd.js.map
