import{a0 as n,o,Y as d,$ as s,a,S as c}from"./index.57388330.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c2cd80a-948c-42c8-9f6c-376c68badddf",e._sentryDebugIdIdentifier="sentry-dbid-8c2cd80a-948c-42c8-9f6c-376c68badddf")}catch{}})();const r={},f={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),d("div",f,[s(e.$slots,"sidebar",{},void 0,!0),a("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",u,[s(e.$slots,"footer",{},void 0,!0)])):c("",!0)])])}const y=n(r,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.e38326c9.js.map
