import{a0 as n,r as t,o as s,c as r}from"./index.57388330.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="0ae276c0-4d6c-4c1f-b3a0-fcec7e60b9bf",e._sentryDebugIdIdentifier="sentry-dbid-0ae276c0-4d6c-4c1f-b3a0-fcec7e60b9bf")}catch{}})();const _={};function d(e,c){const o=t("RouterView");return s(),r(o,{class:"router"})}const f=n(_,[["render",d],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.a01c7ad7.js.map
