import{b as r,u as n}from"./workspaceStore.3e3a3ada.js";import{W as c}from"./PlayerConfigProvider.43b667a4.js";import{d as i,g as d,r as f,u as a,o as p,c as u,w as l,S as _,b as m}from"./index.57388330.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="623c43d4-2fb3-4394-aa4c-43a9cbaea128",t._sentryDebugIdIdentifier="sentry-dbid-623c43d4-2fb3-4394-aa4c-43a9cbaea128")}catch{}})();const h=i({__name:"App",setup(t){const o=r(),e=n();return e.actions.fetch(),d(()=>o.jwt,e.actions.fetch),(w,y)=>{const s=f("RouterView");return a(e).state.workspace?(p(),u(c,{key:0,"main-color":a(e).state.workspace.mainColor,background:a(e).state.workspace.theme,"font-family":a(e).state.workspace.fontFamily,locale:a(e).state.workspace.language},{default:l(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.a4844431.js.map
