import{C as n,A as t}from"./CollapsePanel.6ec92af1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d160531f-8083-4c47-93c9-08b4be8e8f93",e._sentryDebugIdIdentifier="sentry-dbid-d160531f-8083-4c47-93c9-08b4be8e8f93")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.57e7f713.js.map
