import{O as d}from"./workspaceStore.3e3a3ada.js";import{d as i,X as l,o as u,Y as c,b as a,w as n,u as o,aG as s,dd as b,dc as f}from"./index.57388330.js";import"./url.40a6ac51.js";import"./colorHelpers.ae02acb9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6eb8ce01-898a-46bb-a45a-4705b6e995b2",e._sentryDebugIdIdentifier="sentry-dbid-6eb8ce01-898a-46bb-a45a-4705b6e995b2")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(t,r)=>(u(),c("div",null,[a(o(b),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(f),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.903fce23.js.map
