import{U as o,dA as s,dB as i}from"./index.57388330.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="ceed199b-d0fa-41aa-bf0c-65bd8d5a30c8",e._sentryDebugIdIdentifier="sentry-dbid-ceed199b-d0fa-41aa-bf0c-65bd8d5a30c8")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:a,YearPicker:f,TimePicker:b,QuarterPicker:r,RangePicker:d}=s(i),u=o(n,{WeekPicker:t,MonthPicker:a,YearPicker:f,RangePicker:d,TimePicker:b,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e)});export{u as D,a as M,r as Q,d as R,t as W};
//# sourceMappingURL=dayjs.f61a772d.js.map
