import{O as r}from"./workspaceStore.3e3a3ada.js";import{d as l,X as c,o as i,Y as u,b as a,w as o,u as d,aG as n,dd as f,dc as b}from"./index.57388330.js";import"./url.40a6ac51.js";import"./colorHelpers.ae02acb9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8a2cee88-2add-462b-9491-cd5042345cb9",e._sentryDebugIdIdentifier="sentry-dbid-8a2cee88-2add-462b-9491-cd5042345cb9")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(d(f),null,{default:o(()=>[n("You're authenticated")]),_:1}),a(d(b),null,{default:o(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.dde54508.js.map
