import{k as a,T as n,m as r,P as o,C as d,M as p,s as f,n as s,p as c,q as m,t as u,v as g}from"./index.57388330.js";import{s as b,c as y,a as i}from"./workspaceStore.3e3a3ada.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.a4844431.js";import"./url.40a6ac51.js";import"./colorHelpers.ae02acb9.js";import"./PlayerConfigProvider.43b667a4.js";import"./index.ee7e1ab7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="412faa5d-7b56-4930-9834-5f0fb3fd4049",t._sentryDebugIdIdentifier="sentry-dbid-412faa5d-7b56-4930-9834-5f0fb3fd4049")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=a({render:()=>c(l)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",f),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.a4b83f4d.js.map
