import{B as d}from"./BookOutlined.7b183253.js";import{d as b,o as a,c,w as o,b as f,u as n,$ as l,Y as u,aG as i,aS as p,bT as y}from"./index.57388330.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="0273b30b-219c-4ab8-bdbe-d00341f11606",t._sentryDebugIdIdentifier="sentry-dbid-0273b30b-219c-4ab8-bdbe-d00341f11606")}catch{}})();const g=b({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),c(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[f(n(d))]),default:o(()=>[e.$slots.default?l(e.$slots,"default",{key:0}):(a(),u(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.834b9f8a.js.map
