import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.09ec810f.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.57388330.js";import"./gateway.e592f357.js";import"./popupNotifcation.cc3d27fb.js";import"./fetch.9e4ad27a.js";import"./record.82dac5d0.js";import"./SaveButton.1c6ed979.js";import"./UnsavedChangesHandler.d43d61c4.js";import"./ExclamationCircleOutlined.d7c94db5.js";import"./CrudView.b0205a71.js";import"./router.7e66296a.js";import"./Badge.b4017a04.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.834b9f8a.js";import"./BookOutlined.7b183253.js";import"./url.40a6ac51.js";import"./PhDotsThreeVertical.vue.b90e775f.js";import"./index.09157d5c.js";import"./index.1b2729a9.js";import"./asyncComputed.dea6d978.js";import"./polling.99eba4a7.js";import"./PhPencil.vue.945173fd.js";import"./index.8cff4063.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="8083a899-8788-474a-845c-d65faa2e6e45",o._sentryDebugIdIdentifier="sentry-dbid-8083a899-8788-474a-845c-d65faa2e6e45")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.db5b2272.js.map
