import{d as i,o as p,c as n,w as m,b as a,u as t}from"./index.57388330.js";import"./linters.8b6dede8.js";import{W as s}from"./workspaces.cb43da8b.js";import{C as f}from"./ContentLayout.c72cf0b6.js";import{_ as d,E as c}from"./View.vue_vue_type_script_setup_true_lang.09ec810f.js";import"./asyncComputed.dea6d978.js";import"./workspaceStore.3e3a3ada.js";import"./url.40a6ac51.js";import"./colorHelpers.ae02acb9.js";import"./record.82dac5d0.js";import"./gateway.e592f357.js";import"./popupNotifcation.cc3d27fb.js";import"./fetch.9e4ad27a.js";import"./SaveButton.1c6ed979.js";import"./UnsavedChangesHandler.d43d61c4.js";import"./ExclamationCircleOutlined.d7c94db5.js";import"./CrudView.b0205a71.js";import"./router.7e66296a.js";import"./Badge.b4017a04.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.834b9f8a.js";import"./BookOutlined.7b183253.js";import"./PhDotsThreeVertical.vue.b90e775f.js";import"./index.09157d5c.js";import"./index.1b2729a9.js";import"./polling.99eba4a7.js";import"./PhPencil.vue.945173fd.js";import"./index.8cff4063.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="3b34f894-ef39-47c9-91a1-aff28709fd91",o._sentryDebugIdIdentifier="sentry-dbid-3b34f894-ef39-47c9-91a1-aff28709fd91")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(f,null,{default:m(()=>[a(d,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.c4e74449.js.map
